@@ -1,4 +1,4 @@
-// $Id: getinsecurebcaps.c,v 1.1 2004/04/28 17:56:04 ensc Exp $    --*- c -*--
+// $Id: getinsecurebcaps.c 2154 2005-07-15 18:59:55Z ensc $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -32,10 +32,12 @@ vc_get_insecurebcaps()
 	   (1<<VC_CAP_SYS_PACCT) | (1<<VC_CAP_SYS_ADMIN) |
 	   (1<<VC_CAP_SYS_NICE) |
 	   (1<<VC_CAP_SYS_RESOURCE) | (1<<VC_CAP_SYS_TIME) |
-	   (1<<VC_CAP_MKNOD) | (1<<VC_CAP_QUOTACTL)
+	   (1<<VC_CAP_MKNOD) | (1<<VC_CAP_AUDIT_CONTROL)
+	   | ~(0x7fffffff)
 
 #if defined(VC_ENABLE_API_COMPAT)
 	   | (vc_isSupported(vcFEATURE_VSHELPER) ? 0 : (1<<VC_CAP_SYS_BOOT))
+	   | (vc_isSupported(vcFEATURE_MIGRATE)  ? 0 : (1<<29)) // formerly QUOTACTL
 #endif
     );
 }
