@@ -1,4 +1,4 @@
-// $Id: syscall_ctxcreate.c,v 1.1 2004/04/14 23:19:51 ensc Exp $    --*- c -*--
+// $Id: syscall_ctxcreate.c 2207 2005-10-29 10:31:42Z ensc $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -22,7 +22,7 @@
 
 #include "vserver.h"
 #include "vserver-internal.h"
-#include "linuxvirtual.h"
+#include "virtual.h"
 
 #if defined(VC_ENABLE_API_V13)
 #  include "syscall_ctxcreate-v13.hc"
