@@ -1,4 +1,4 @@
-// $Id: virtual.h,v 1.20 2004/03/12 03:37:31 ensc Exp $    --*- c -*--
+// $Id: virtual.h 2415 2006-12-08 13:24:49Z dhozac $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -19,12 +19,18 @@
 #ifndef H_UTIL_VSERVER_LIB_VIRTUAL_H
 #define H_UTIL_VSERVER_LIB_VIRTUAL_H
 
-#include <kernel/context.h>
+#include <kernel/context_cmd.h>
+#include <kernel/cvirt_cmd.h>
+#include <kernel/cvirt_cmd.h>
+#include <kernel/dlimit_cmd.h>
+#include <kernel/inode_cmd.h>
+#include <kernel/limit_cmd.h>
+#include <kernel/space_cmd.h>
+#include <kernel/network.h>
+#include <kernel/network_cmd.h>
+#include <kernel/sched_cmd.h>
+#include <kernel/signal_cmd.h>
+
 #include <kernel/legacy.h>
-#include <kernel/limit.h>
-#include <kernel/signal.h>
-#include <kernel/namespace.h>
-#include <kernel/inode.h>
-#include <kernel/sched.h>
 
 #endif	//  H_UTIL_VSERVER_LIB_VIRTUAL_H
