@@ -1,4 +1,4 @@
-// $Id: util.h,v 1.6 2005/07/04 22:35:47 ensc Exp $    --*- c -*--
+// $Id: util.h 2255 2006-01-22 11:23:47Z ensc $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -35,6 +35,7 @@
 
 bool		switchToWatchXid(char const **);
 size_t		canonifyVserverName(char *);
-bool		isNumber(char const *, signed long *result);
+bool		isNumber(char const *, signed long *result, bool is_strict);
+bool		isNumberUnsigned(char const *, unsigned long *result, bool is_strict);
 
 #endif	//  H_UTILVSERVER_LIB_INTERNAL_UTIL_H
