@@ -1,4 +1,4 @@
-// $Id: readlink.c,v 1.3 2004/04/28 18:11:03 ensc Exp $
+// $Id: readlink.c 1980 2005-03-24 12:44:17Z ensc $
 
 // Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -71,7 +71,7 @@ int main (int argc, char *argv[])
     PERROR_Q("readlink: readlink", argv[idx]);
   else {
     buf[len++] = '\n';
-    write(1, buf, len);
+    Vwrite(1, buf, len);
     return EXIT_SUCCESS;
   }
 
