@@ -1,4 +1,4 @@
-// $Id: interface-print.c,v 1.1 2004/08/19 15:02:56 ensc Exp $    --*- c -*--
+// $Id: interface-print.c 1939 2005-03-19 02:07:40Z ensc $    --*- c -*--
 
 // Copyright (C) 2004 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
 //  
@@ -23,7 +23,7 @@
 #include "interface.h"
 
 void
-Iface_print(struct Interface const *iface, int fd)
+Iface_print(struct Interface const UNUSED *iface, int UNUSED fd)
 {
   
 }
